==> zio-aws-sagemaker_3-5.17.233.1-sources.jar: zio/aws/sagemaker/model/TrafficPattern.scala <==
package zio.aws.sagemaker.model
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import zio.prelude.data.Optional
import scala.jdk.CollectionConverters.*
final case class TrafficPattern(
    trafficType: Optional[zio.aws.sagemaker.model.TrafficType] =
      Optional.Absent,
    phases: Optional[Iterable[zio.aws.sagemaker.model.Phase]] = Optional.Absent
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.sagemaker.model.TrafficPattern = {
    import TrafficPattern.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.sagemaker.model.TrafficPattern
      .builder()
      .optionallyWith(trafficType.map(value => value.unwrap))(_.trafficType)
      .optionallyWith(
        phases.map(value =>
          value.map { item =>
            item.buildAwsValue()
          }.asJavaCollection
        )
      )(_.phases)
      .build()
  }
  def asReadOnly: zio.aws.sagemaker.model.TrafficPattern.ReadOnly =
    zio.aws.sagemaker.model.TrafficPattern.wrap(buildAwsValue())
}
object TrafficPattern {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.sagemaker.model.TrafficPattern
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.sagemaker.model.TrafficPattern =
      zio.aws.sagemaker.model.TrafficPattern(
        trafficType.map(value => value),
        phases.map(value =>
          value.map { item =>
            item.asEditable
          }
        )
      )
    def trafficType: Optional[zio.aws.sagemaker.model.TrafficType]
    def phases: Optional[List[zio.aws.sagemaker.model.Phase.ReadOnly]]
    def getTrafficType
        : ZIO[Any, AwsError, zio.aws.sagemaker.model.TrafficType] =
      AwsError.unwrapOptionField("trafficType", trafficType)
    def getPhases
        : ZIO[Any, AwsError, List[zio.aws.sagemaker.model.Phase.ReadOnly]] =
      AwsError.unwrapOptionField("phases", phases)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.sagemaker.model.TrafficPattern
  ) extends zio.aws.sagemaker.model.TrafficPattern.ReadOnly {
    override val trafficType: Optional[zio.aws.sagemaker.model.TrafficType] =
      zio.aws.core.internal
        .optionalFromNullable(impl.trafficType())
        .map(value => zio.aws.sagemaker.model.TrafficType.wrap(value))
    override val phases
        : Optional[List[zio.aws.sagemaker.model.Phase.ReadOnly]] =
      zio.aws.core.internal
        .optionalFromNullable(impl.phases())
        .map(value =>
          value.asScala.map { item =>
            zio.aws.sagemaker.model.Phase.wrap(item)
          }.toList
        )
  }
  def wrap(
      impl: software.amazon.awssdk.services.sagemaker.model.TrafficPattern
  ): zio.aws.sagemaker.model.TrafficPattern.ReadOnly = new Wrapper(impl)
}

==> zio-aws-sagemaker_3-7.21.15.7-sources.jar: zio/aws/sagemaker/model/TrafficPattern.scala <==
package zio.aws.sagemaker.model
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import zio.prelude.data.Optional
import scala.jdk.CollectionConverters.*
final case class TrafficPattern(
    trafficType: Optional[zio.aws.sagemaker.model.TrafficType] =
      Optional.Absent,
    phases: Optional[Iterable[zio.aws.sagemaker.model.Phase]] = Optional.Absent,
    stairs: Optional[zio.aws.sagemaker.model.Stairs] = Optional.Absent
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.sagemaker.model.TrafficPattern = {
    import TrafficPattern.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.sagemaker.model.TrafficPattern
      .builder()
      .optionallyWith(trafficType.map(value => value.unwrap))(_.trafficType)
      .optionallyWith(
        phases.map(value =>
          value.map { item =>
            item.buildAwsValue()
          }.asJavaCollection
        )
      )(_.phases)
      .optionallyWith(stairs.map(value => value.buildAwsValue()))(_.stairs)
      .build()
  }
  def asReadOnly: zio.aws.sagemaker.model.TrafficPattern.ReadOnly =
    zio.aws.sagemaker.model.TrafficPattern.wrap(buildAwsValue())
}
object TrafficPattern {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.sagemaker.model.TrafficPattern
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.sagemaker.model.TrafficPattern =
      zio.aws.sagemaker.model.TrafficPattern(
        trafficType.map(value => value),
        phases.map(value =>
          value.map { item =>
            item.asEditable
          }
        ),
        stairs.map(value => value.asEditable)
      )
    def trafficType: Optional[zio.aws.sagemaker.model.TrafficType]
    def phases: Optional[List[zio.aws.sagemaker.model.Phase.ReadOnly]]
    def stairs: Optional[zio.aws.sagemaker.model.Stairs.ReadOnly]
    def getTrafficType
        : ZIO[Any, AwsError, zio.aws.sagemaker.model.TrafficType] =
      AwsError.unwrapOptionField("trafficType", trafficType)
    def getPhases
        : ZIO[Any, AwsError, List[zio.aws.sagemaker.model.Phase.ReadOnly]] =
      AwsError.unwrapOptionField("phases", phases)
    def getStairs: ZIO[Any, AwsError, zio.aws.sagemaker.model.Stairs.ReadOnly] =
      AwsError.unwrapOptionField("stairs", stairs)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.sagemaker.model.TrafficPattern
  ) extends zio.aws.sagemaker.model.TrafficPattern.ReadOnly {
    override val trafficType: Optional[zio.aws.sagemaker.model.TrafficType] =
      zio.aws.core.internal
        .optionalFromNullable(impl.trafficType())
        .map(value => zio.aws.sagemaker.model.TrafficType.wrap(value))
    override val phases
        : Optional[List[zio.aws.sagemaker.model.Phase.ReadOnly]] =
      zio.aws.core.internal
        .optionalFromNullable(impl.phases())
        .map(value =>
          value.asScala.map { item =>
            zio.aws.sagemaker.model.Phase.wrap(item)
          }.toList
        )
    override val stairs: Optional[zio.aws.sagemaker.model.Stairs.ReadOnly] =
      zio.aws.core.internal
        .optionalFromNullable(impl.stairs())
        .map(value => zio.aws.sagemaker.model.Stairs.wrap(value))
  }
  def wrap(
      impl: software.amazon.awssdk.services.sagemaker.model.TrafficPattern
  ): zio.aws.sagemaker.model.TrafficPattern.ReadOnly = new Wrapper(impl)
}
